@@ -70,23 +70,29 @@
 #'                               angio = c("Negative", "Positive"))
 #' decision3 <- compileDecisionModel(Net, custom_policy) 
 #' 
-compileDecisionModel <- function(network, policyMatrix = NULL, ..., data = NULL){
-  Check <- ArgumentCheck::newArgCheck()
-  
+compileDecisionModel <- function(network, policyMatrix = NULL, ..., data = NULL)
+{
+  coll <- checkmate::makeAssertCollection()
+
   dots <- list(...)
   
-  options <- makePolicyMatrix(network, policyMatrix, data, Check)
+  options <- 
+    makePolicyMatrix(network = network, 
+                     policyMatrix = policyMatrix, 
+                     data = data, 
+                     argcheck = coll
+    )
 
-  ArgumentCheck::finishArgCheck(Check)
+  checkmate::reportAssertions(coll)
+
+  cpt_arrays <- makeCptArrays(network = network)
   
-  cpt_arrays <- makeCptArrays(network)
-  
-  jags.code <- compileJagsModel(network, ...)
+  jags.code <- compileJagsModel(network = network, ...)
 
   lapply(options,
          runJagsDecisionModel,
-         jags.code,
-         cpt_arrays, 
+         j = jags.code,
+         cpt_arrays = cpt_arrays, 
          ...)
   
   
@@ -95,118 +101,162 @@ compileDecisionModel <- function(network, policyMatrix = NULL, ..., data = NULL)
 
 #*********** UTILITY FUNCTIONS
 
-makePolicyMatrix <- function(network, policyMatrix, data, argcheck){
+makePolicyMatrix <- function(network, policyMatrix, data, argcheck)
+{
   if (is.null(policyMatrix))
   {
-    decisionNodes <- names(network$nodeDecision)[sapply(network$nodeDecision, any)]
+    decisionNodes <- 
+      names(network[["nodeDecision"]])[vapply(X = network[["nodeDecision"]], 
+                                              FUN = any, 
+                                              FUN.VALUE = logical(1))]
     
-    if (length(decisionNodes) == 0)
-      ArgumentCheck::addError(
-        msg = "No decision nodes indicated in the network",
-        argcheck = argcheck)
+    validDecision <- 
+      network[["nodeType"]][decisionNodes] %>%
+      unlist()
+
+    inSubset <- 
+      checkmate::testSubset(validDecision,
+                            choices = c("dbern", "dcat", "dbin"),
+                            empty.ok = FALSE
+      )
     
-    if (length(decisionNodes) == 0) break; # The next argument check isn't meaningful
-    # when this condition is true.
-    
-    validDecision <- sapply(network$nodeType[decisionNodes], 
-                            function(x) x %in% c("dbern", "dcat", "dbin"))
-    
-    if (!all(validDecision))
-      ArgumentCheck::addError(
-        msg = paste0("Only nodes of type 'dcat', and 'dbin' may be decision nodes.\n  ",
-                     paste0(names(validDecision)[!validDecision], collapse=", "),
-                     " cannot be used as decision nodes."),
-        argcheck = argcheck)
-    
-    if (!all(validDecision)) break; # Avoids defining 'options' when there are invalid decision nodes
-    
-    options <- lapply(decisionNodes, decisionOptions, network)
-    names(options) <- decisionNodes
+    if (!inSubset) 
+    {
+      argcheck$push(
+        paste0(
+          "Decision nodes must be of type 'dbern', 'dcat', or 'dbin'.\n   ",
+          paste0(names(validDecision)[!validDecision], collapse=", "),
+          " cannot be used as decision nodes."
+        )
+      )
+    }
     
+    checkmate::reportAssertions(argcheck)
+
+    options <- lapply(X = decisionNodes, 
+                      FUN = decisionOptions, 
+                      network = network) %>%
+      stats::setNames(decisionNodes)
+
     options <- expand.grid(options, stringsAsFactors=FALSE) 
   }
   else
   {
-    if (!is.data.frame(policyMatrix))
-      ArgumentCheck::addError(
-        msg = "'policyMatrix' must be a data frame",
-        argcheck = argcheck)
-    if (!is.data.frame(policyMatrix)) break; # avoids defining 'options' when
-    # the condition is not satisfied
+    checkmate::assertDataFrame(policyMatrix,
+                               add = argcheck)
+
+    checkmate::reportAssertions(argcheck)
+    
     options <- policyMatrix
   }
   
   #* This is the part that pushes values from `data` into the 
   #* policy matrix.
-  if (!is.null(data)){
+  if (!is.null(data))
+  {
     conflicts <- names(data)[names(data) %in% names(options)]
-    if (length(conflicts) > 0){
-      ArgumentCheck::addWarning(
-        msg = paste0("The following variables in 'data' are overriding ",
-                     "values in 'policyMatrix': ",
-                     paste0(conflicts, collapse = ", ")),
-        argcheck = argcheck)
+    
+    if (length(conflicts) > 0)
+    {
+      warning("The following variables in 'data' are overriding ",
+              "values in 'policyMatrix': ",
+              paste0(conflicts, collapse = ", ")
+      )
     }
     
-    for (i in names(data)){
+    for (i in names(data))
+    {
       options[[i]] <- data[[i]]
     }
     #* Remove duplicated rows
     options <- options[!duplicated(options), , drop = FALSE]
   }
   
-  ArgumentCheck::finishArgCheck(argcheck)
+  options <- 
+    lapply(X = 1:nrow(options), 
+           FUN = function(i)
+                 { 
+                    l <- as.list(options[i, , drop=FALSE])
+                    nms <- names(l)
+                    attributes(l) <- NULL
+                    names(l) <- nms
+                    l
+                  }
+           )
   
-  options <- lapply(1:nrow(options), 
-                    function(i){ 
-                      l <- as.list(options[i, , drop=FALSE])
-                      nms <- names(l)
-                      attributes(l) <- NULL
-                      names(l) <- nms
-                      l
-                    })
-  
-  return(options)
+  options
 }
 
 #**
 
 
 
-makeCptArrays <- function(network){
+makeCptArrays <- function(network)
+{
   cpt_arrays <- unlist(network$nodeFitter) == "cpt"
-  if(any(cpt_arrays)){
+  if(any(cpt_arrays))
+  {
     cpt_arrays <- names(cpt_arrays)[cpt_arrays]
-    cpt_arrays <- network$nodeModel[cpt_arrays]
+    cpt_arrays <- network[["nodeModel"]][cpt_arrays]
     nms <- names(cpt_arrays)
     cpt_arrays <- 
-      lapply(names(cpt_arrays),
-             function(ca){
-               if ("cpt" %in% class(cpt_arrays[[ca]])) return(cpt_arrays[[ca]])
-               else{
-                 args <- 
-                   list(formula = network$nodeFormula[[ca]],
-                        data = if (!is.null(network$nodeData[[ca]])) network$nodeData[[ca]]
-                        else network$data)
-                 if (!is.null(network$nodeFitterArgs[[ca]]))
-                   args <- c(args, network$nodeFitterArgs[[ca]])
-                 return(do.call("cpt", args))
-               }   
-             })
+      lapply(X = names(cpt_arrays),
+             FUN = 
+               function(ca)
+               {
+                  if ("cpt" %in% class(cpt_arrays[[ca]]))
+                  {
+                    return(cpt_arrays[[ca]])
+                  }
+                  else
+                  {
+                      args <-
+                        list(formula = network[["nodeFormula"]][[ca]],
+                             data = if (!is.null(network$nodeData[[ca]]))
+                                    {
+                                      network$nodeData[[ca]]
+                                    }
+                                    else 
+                                    {
+                                      network$data
+                                    }
+                             )
+                      if (!is.null(network[["nodeFitterArgs"]][[ca]]))
+                      {
+                        args <- c(args, network[["nodeFitterArgs"]][[ca]])
+                      }
+                      return(do.call("cpt", args))
+                  }   
+             }
+          )
     names(cpt_arrays) <- paste0("cpt.", nms)
-  } else cpt_arrays = list()
+  } 
+  else 
+  {
+    cpt_arrays = list()
+  }
   return(cpt_arrays) 
 }
 
 #****
+#* o: element of the options list
+#* j: jags code 
+#* cpt_arrays: the conditional probability table arrays
 
-runJagsDecisionModel <- function(o, j, cpt_arrays, ...){
-  con <- textConnection(paste0(j$jags$model(),
-                                 collapse="\n"))
-  o_character <- vapply(o, is.character, logical(1))
-  for (i in seq_along(o)){
+runJagsDecisionModel <- function(o, j, cpt_arrays, ...)
+{
+  con <- textConnection(paste0(j[["jags"]]$model(),
+                               collapse="\n")
+                        )
+  o_character <- vapply(X = o, 
+                        FUN = is.character, 
+                        FUN.VALUE = logical(1))
+  for (i in seq_along(o))
+  {
     if (o_character[i])
-      o[[i]] <- j$factorRef[[names(o[i])]]$value[j$factorRef[[names(o[i])]]$label == o[[i]]]
+    {
+      o[[i]] <- j[["factorRef"]][[names(o[i])]][["value"]][j[["factorRef"]][[names(o[i])]][["label"]] == o[[i]]]
+    }
   }
   
   cHN <- list(jags = rjags::jags.model(con,
@@ -217,5 +267,5 @@ runJagsDecisionModel <- function(o, j, cpt_arrays, ...){
               factorRef = j$factorRef)
   class(cHN) <- c("compiledHydeNetwork")
   close(con)
-  return(cHN)
+  cHN
 }  
